using csUnit;
using Esb.Math;

namespace EsbMathTests
{
	/// <summary>
	/// Tests for the ESBPCS Math Compare Methods
	/// </summary>
	[TestFixture]
	public class MathCompareTest
	{
		public MathCompareTest()
		{
		}

		
		[Test]
		public void SameValue_1()
		{
			Assert.True (CompareOps.SameValue (1.23456, 1.23456));
		}
		[Test]
		public void SameValue_2()
		{
			Assert.True (CompareOps.SameValue (-1.23456, -1.23456));
		}
		[Test]
		public void SameValue_3()
		{
			Assert.True (CompareOps.SameValue (0.0, 0.0));
		}
		[Test]
		public void SameValue_4()
		{
			Assert.False (CompareOps.SameValue (1.234567, 1.23456));
		}
		[Test]
		public void SameValue_5()
		{
			Assert.True (CompareOps.SameValue (1.234f, 1.234f));
		}
		[Test]
		public void SameValue_6()
		{
			Assert.True (CompareOps.SameValue (-1.234f, -1.234f));
		}
		[Test]
		public void SameValue_7()
		{
			Assert.True (CompareOps.SameValue (0.0f, 0.0f));
		}
		[Test]
		public void SameValue_8()
		{
			Assert.False (CompareOps.SameValue (1.2345f, 1.234f));
		}
		[Test]
		public void SameValue_9()
		{
			Assert.True (CompareOps.SameValue (1.2345678901234567890m, 1.2345678901234567890m));
		}
		[Test]
		public void SameValue_10()
		{
			Assert.True (CompareOps.SameValue (-1.2345678901234567890m, -1.2345678901234567890m));
		}
		[Test]
		public void SameValue_11()
		{
			Assert.True (CompareOps.SameValue (0.0m, 0.0m));
		}
		[Test]
		public void SameValue_12()
		{
			Assert.False (CompareOps.SameValue (1.23456789012345678901m, 1.2345678901234567890m));
		}

		[Test]
		public void CompareValue_1()
		{
			Assert.Equals (CompareOps.CompareValue (1.23456, 1.23456), 0);
		}
		[Test]
		public void CompareValue_2()
		{
			Assert.Equals (CompareOps.CompareValue (1.23456, 5.23456), -1);
		}
		[Test]
		public void CompareValue_3()
		{
			Assert.Equals (CompareOps.CompareValue (5.23456, 1.23456), 1);
		}
		[Test]
		public void CompareValue_4()
		{
			Assert.Equals (CompareOps.CompareValue (1.234f, 1.234f), 0);
		}
		[Test]
		public void CompareValue_5()
		{
			Assert.Equals (CompareOps.CompareValue (1.234f, 5.234f), -1);
		}
		[Test]
		public void CompareValue_6()
		{
			Assert.Equals (CompareOps.CompareValue (5.234f, 1.234f), 1);
		}
		[Test]
		public void CompareValue_7()
		{
			Assert.Equals (CompareOps.CompareValue (1.2345678901234567890m, 1.2345678901234567890m), 0);
		}
		[Test]
		public void CompareValue_8()
		{
			Assert.Equals (CompareOps.CompareValue (1.2345678901234567890m, 1.23456789012345678901m), -1);
		}
		[Test]
		public void CompareValue_9()
		{
			Assert.Equals (CompareOps.CompareValue (1.23456789012345678901m, 1.2345678901234567890m), 1);
		}

		[Test]
		public void Greater_1()
		{
			Assert.False (CompareOps.GreaterValue (1.23456, 1.23456));
		}
		[Test]
		public void Greater_2()
		{
			Assert.True (CompareOps.GreaterValue (21.23456, 1.23456));
		}
		[Test]
		public void Greater_3()
		{
			Assert.False (CompareOps.GreaterValue (1.23456, 31.23456));
		}
		[Test]
		public void Greater_4()
		{
			Assert.False (CompareOps.GreaterValue (1.234f, 1.234f));
		}
		[Test]
		public void Greater_5()
		{
			Assert.True (CompareOps.GreaterValue (21.234f, 1.234f));
		}
		[Test]
		public void Greater_6()
		{
			Assert.False (CompareOps.GreaterValue (1.234f, 31.234f));
		}
		[Test]
		public void Greater_7()
		{
			Assert.False (CompareOps.GreaterValue (1.2345678901234567890m, 1.2345678901234567890m));
		}
		[Test]
		public void Greater_8()
		{
			Assert.True (CompareOps.GreaterValue (21.2345678901234567890m, 1.2345678901234567890m));
		}
		[Test]
		public void Greater_9()
		{
			Assert.False (CompareOps.GreaterValue (1.2345678901234567890m, 31.2345678901234567890m));
		}

		[Test]
		public void Lesser_1()
		{
			Assert.False (CompareOps.LesserValue (1.23456, 1.23456));
		}
		[Test]
		public void Lesser_2()
		{
			Assert.False (CompareOps.LesserValue (21.23456, 1.23456));
		}
		[Test]
		public void Lesser_3()
		{
			Assert.True (CompareOps.LesserValue (1.23456, 31.23456));
		}
		[Test]
		public void Lesser_4()
		{
			Assert.False (CompareOps.LesserValue (1.234f, 1.234f));
		}
		[Test]
		public void Lesser_5()
		{
			Assert.False (CompareOps.LesserValue (21.234f, 1.234f));
		}
		[Test]
		public void Lesser_6()
		{
			Assert.True (CompareOps.LesserValue (1.234f, 31.234f));
		}
		[Test]
		public void Lesser_7()
		{
			Assert.False (CompareOps.LesserValue (1.2345678901234567890m, 1.2345678901234567890m));
		}
		[Test]
		public void Lesser_8()
		{
			Assert.False (CompareOps.LesserValue (21.2345678901234567890m, 1.2345678901234567890m));
		}
		[Test]
		public void Lesser_9()
		{
			Assert.True (CompareOps.LesserValue (1.2345678901234567890m, 31.2345678901234567890m));
		}

		[Test]
		public void ValueIsZero_1()
		{
			Assert.True (CompareOps.ValueIsZero (0.0));
		}
		[Test]
		public void ValueIsZero_2()
		{
			Assert.False (CompareOps.ValueIsZero (1.5));
		}
		[Test]
		public void ValueIsZero_3()
		{
			Assert.False (CompareOps.ValueIsZero (-23.45));
		}
		[Test]
		public void ValueIsZero_4()
		{
			Assert.True (CompareOps.ValueIsZero (CompareOps.DoublePrecisionDef));
		}
		[Test]
		public void ValueIsZero_5()
		{
			Assert.False (CompareOps.ValueIsZero (CompareOps.DoublePrecisionDef * 10.0));
		}
		[Test]
		public void ValueIsZero_6()
		{
			Assert.True (CompareOps.ValueIsZero (-CompareOps.DoublePrecisionDef));
		}
		[Test]
		public void ValueIsZero_7()
		{
			Assert.False (CompareOps.ValueIsZero (-CompareOps.DoublePrecisionDef * 10.0));
		}
		[Test]
		public void ValueIsZero_8()
		{
			Assert.True (CompareOps.ValueIsZero (0.0f));
		}
		[Test]
		public void ValueIsZero_9()
		{
			Assert.False (CompareOps.ValueIsZero (1.5f));
		}
		[Test]
		public void ValueIsZero_10()
		{
			Assert.False (CompareOps.ValueIsZero (-23.45f));
		}
		[Test]
		public void ValueIsZero_11()
		{
			Assert.True (CompareOps.ValueIsZero (CompareOps.FloatPrecisionDef));
		}
		[Test]
		public void ValueIsZero_12()
		{
			Assert.False (CompareOps.ValueIsZero (CompareOps.FloatPrecisionDef * 10.0f));
		}
		[Test]
		public void ValueIsZero_13()
		{
			Assert.True (CompareOps.ValueIsZero (-CompareOps.FloatPrecisionDef));
		}
		[Test]
		public void ValueIsZero_14()
		{
			Assert.False (CompareOps.ValueIsZero (-CompareOps.FloatPrecisionDef * 10.0f));
		}
		[Test]
		public void ValueIsZero_15()
		{
			Assert.True (CompareOps.ValueIsZero (0.0m));
		}
		[Test]
		public void ValueIsZero_16()
		{
			Assert.False (CompareOps.ValueIsZero (1.5m));
		}
		[Test]
		public void ValueIsZero_17()
		{
			Assert.False (CompareOps.ValueIsZero (-23.45m));
		}
		[Test]
		public void ValueIsZero_18()
		{
			Assert.True (CompareOps.ValueIsZero (CompareOps.DecimalPrecisionDef));
		}
		[Test]
		public void ValueIsZero_19()
		{
			Assert.False (CompareOps.ValueIsZero (CompareOps.DecimalPrecisionDef * 10.0m));
		}
		[Test]
		public void ValueIsZero_20()
		{
			Assert.True (CompareOps.ValueIsZero (-CompareOps.DecimalPrecisionDef));
		}
		[Test]
		public void ValueIsZero_21()
		{
			Assert.False (CompareOps.ValueIsZero (-CompareOps.DecimalPrecisionDef * 10.0m));
		}

		[Test]
		public void ValueIsPositive_1()
		{
			Assert.False (CompareOps.ValueIsPositive (0.0));
		}
		[Test]
		public void ValueIsPositive_2()
		{
			Assert.True (CompareOps.ValueIsPositive (12.34567));
		}
		[Test]
		public void ValueIsPositive_3()
		{
			Assert.False (CompareOps.ValueIsPositive (-12.34567));
		}
		[Test]
		public void ValueIsPositive_4()
		{
			Assert.False (CompareOps.ValueIsPositive (CompareOps.DoublePrecisionDef));
		}
		[Test]
		public void ValueIsPositive_5()
		{
			Assert.True (CompareOps.ValueIsPositive (CompareOps.DoublePrecisionDef * 10.0));
		}
		[Test]
		public void ValueIsPositive_6()
		{
			Assert.False (CompareOps.ValueIsPositive (0.0f));
		}
		[Test]
		public void ValueIsPositive_7()
		{
			Assert.True (CompareOps.ValueIsPositive (12.34f));
		}
		[Test]
		public void ValueIsPositive_8()
		{
			Assert.False (CompareOps.ValueIsPositive (-12.34f));
		}
		[Test]
		public void ValueIsPositive_9()
		{
			Assert.False (CompareOps.ValueIsPositive (CompareOps.FloatPrecisionDef));
		}
		[Test]
		public void ValueIsPositive_10()
		{
			Assert.True (CompareOps.ValueIsPositive (CompareOps.FloatPrecisionDef * 10.0f));
		}
		[Test]
		public void ValueIsPositive_11()
		{
			Assert.False (CompareOps.ValueIsPositive (0.0m));
		}
		[Test]
		public void ValueIsPositive_12()
		{
			Assert.True (CompareOps.ValueIsPositive (12.345678901234567890m));
		}
		[Test]
		public void ValueIsPositive_13()
		{
			Assert.False (CompareOps.ValueIsPositive (-12.345678901234567890m));
		}
		[Test]
		public void ValueIsPositive_14()
		{
			Assert.False (CompareOps.ValueIsPositive (CompareOps.DecimalPrecisionDef));
		}
		[Test]
		public void ValueIsPositive_15()
		{
			Assert.True (CompareOps.ValueIsPositive (CompareOps.DecimalPrecisionDef * 10.0m));
		}
	}
}
