using csUnit;

using Esb.Math;

namespace EsbMathTests
{
	/// <summary>
	/// Tests for the ESBPCS Math Integer Methods
	/// </summary>
	[TestFixture]
	public class MathIntTest
	{

		public MathIntTest()
		{
		}

		[Test]
		public void Odd_1()
		{
			Assert.False (IntOps.Odd (0));
		}
		[Test]
		public void Odd_2()
		{
			Assert.True (IntOps.Odd (1));
		}
		[Test]
		public void Odd_3()
		{
			Assert.True (IntOps.Odd (-1));
		}
		[Test]
		public void Odd_4()
		{
			Assert.False (IntOps.Odd (2));
		}
		[Test]
		public void Odd_5()
		{
			Assert.False (IntOps.Odd (123456));
		}
		[Test]
		public void Odd_6()
		{
			Assert.True (IntOps.Odd (1234567));
		}
		[Test]
		public void Odd_7()
		{
			Assert.False (IntOps.Odd (-123456));
		}
		[Test]
		public void Odd_8()
		{
			Assert.True (IntOps.Odd (-1234567));
		}
		[Test]
		public void Odd_9()
		{
			Assert.True (IntOps.Odd (-1234567890123L));
		}
		[Test]
		public void Odd_10()
		{
			Assert.False (IntOps.Odd (12345678901234L));
		}

		[Test]
		public void Floor_1()
		{
			Assert.Equals (IntOps.Floor (0.0), 0);
		}
		[Test]
		public void Floor_2()
		{
			Assert.Equals (IntOps.Floor (1.5), 1);
		}
		[Test]
		public void Floor_3()
		{
			Assert.Equals (IntOps.Floor (-1.5), -2);
		}
		[Test]
		public void Floor_4()
		{
			Assert.Equals (IntOps.Floor (123.999999), 123);
		}
		[Test]
		public void Floor_5()
		{
			Assert.Equals (IntOps.Floor (-123.999999), -124);
		}
		[Test]
		public void Floor_6()
		{
			Assert.Equals (IntOps.Floor (0.0m), 0);
		}
		[Test]
		public void Floor_7()
		{
			Assert.Equals (IntOps.Floor (1.5m), 1);
		}
		[Test]
		public void Floor_8()
		{
			Assert.Equals (IntOps.Floor (-1.5m), -2);
		}
		[Test]
		public void Floor_9()
		{
			Assert.Equals (IntOps.Floor (123.999999m), 123);
		}
		[Test]
		public void Floor_10()
		{
			Assert.Equals (IntOps.Floor (-123.999999m), -124);
		}

		[Test]
		public void Floor64_1()
		{
			Assert.Equals (IntOps.Floor64 (0.0), 0L);
		}
		[Test]
		public void Floor64_2()
		{
			Assert.Equals (IntOps.Floor64 (1.5), 1L);
		}
		[Test]
		public void Floor64_3()
		{
			Assert.Equals (IntOps.Floor64 (-1.5), -2L);
		}
		[Test]
		public void Floor64_4()
		{
			Assert.Equals (IntOps.Floor64 (12345678901234.99), 12345678901234L);
		}
		[Test]
		public void Floor64_5()
		{
			Assert.Equals (IntOps.Floor64 (-12345678901234.99), -12345678901235L);
		}
		[Test]
		public void Floor64_6()
		{
			Assert.Equals (IntOps.Floor64 (0.0m), 0L);
		}
		[Test]
		public void Floor64_7()
		{
			Assert.Equals (IntOps.Floor64 (1.5m), 1L);
		}
		[Test]
		public void Floor64_8()
		{
			Assert.Equals (IntOps.Floor64 (-1.5m), -2L);
		}
		[Test]
		public void Floor64_9()
		{
			Assert.Equals (IntOps.Floor64 (12345678901234.999999m), 12345678901234L);
		}
		[Test]
		public void Floor64_10()
		{
			Assert.Equals (IntOps.Floor64 (-12345678901234.999999m), -12345678901235L);
		}

		[Test]
		public void Ceiling_1()
		{
			Assert.Equals (IntOps.Ceiling (0.0), 0);
		}
		[Test]
		public void Ceiling_2()
		{
			Assert.Equals (IntOps.Ceiling (1.5), 2);
		}
		[Test]
		public void Ceiling_3()
		{
			Assert.Equals (IntOps.Ceiling (-1.5), -1);
		}
		[Test]
		public void Ceiling_4()
		{
			Assert.Equals (IntOps.Ceiling (123.999999), 124);
		}
		[Test]
		public void Ceiling_5()
		{
			Assert.Equals (IntOps.Ceiling (-123.999999), -123);
		}
		[Test]
		public void Ceiling_6()
		{
			Assert.Equals (IntOps.Ceiling (0.0m), 0);
		}
		[Test]
		public void Ceiling_7()
		{
			Assert.Equals (IntOps.Ceiling (1.5m), 2);
		}
		[Test]
		public void Ceiling_8()
		{
			Assert.Equals (IntOps.Ceiling (-1.5m), -1);
		}
		[Test]
		public void Ceiling_9()
		{
			Assert.Equals (IntOps.Ceiling (123.999999m), 124);
		}
		[Test]
		public void Ceiling_10()
		{
			Assert.Equals (IntOps.Ceiling (-123.999999m), -123);
		}

		[Test]
		public void Ceiling64_1()
		{
			Assert.Equals (IntOps.Ceiling64 (0.0), 0L);
		}
		[Test]
		public void Ceiling64_2()
		{
			Assert.Equals (IntOps.Ceiling64 (1.5), 2L);
		}
		[Test]
		public void Ceiling64_3()
		{
			Assert.Equals (IntOps.Ceiling64 (-1.5), -1L);
		}
		[Test]
		public void Ceiling64_4()
		{
			Assert.Equals (IntOps.Ceiling64 (12345678901234.99), 12345678901235L);
		}
		[Test]
		public void Ceiling64_5()
		{
			Assert.Equals (IntOps.Ceiling64 (-12345678901234.99), -12345678901234L);
		}
		[Test]
		public void Ceiling64_6()
		{
			Assert.Equals (IntOps.Ceiling64 (0.0m), 0L);
		}
		[Test]
		public void Ceiling64_7()
		{
			Assert.Equals (IntOps.Ceiling64 (1.5m), 2L);
		}
		[Test]
		public void Ceiling64_8()
		{
			Assert.Equals (IntOps.Ceiling64 (-1.5m), -1L);
		}
		[Test]
		public void Ceiling64_9()
		{
			Assert.Equals (IntOps.Ceiling64 (12345678901234.999999m), 12345678901235L);
		}
		[Test]
		public void Ceiling64_10()
		{
			Assert.Equals (IntOps.Ceiling64 (-12345678901234.999999m), -12345678901234L);
		}

		[Test]
		public void IntPart_1 ()
		{
			Assert.Equals (IntOps.IntPart (0.123), 0);
		}
		[Test]
		public void IntPart_2 ()
		{
			Assert.Equals (IntOps.IntPart (-0.123), 0);
		}
		[Test]
		public void IntPart_3 ()
		{
			Assert.Equals (IntOps.IntPart (123.456), 123);
		}
		[Test]
		public void IntPart_4 ()
		{
			Assert.Equals (IntOps.IntPart (-123.456), -123);
		}
		[Test]
		public void IntPart_5 ()
		{
			Assert.Equals (IntOps.IntPart (0.123m), 0);
		}
		[Test]
		public void IntPart_6 ()
		{
			Assert.Equals (IntOps.IntPart (-0.123m), 0);
		}
		[Test]
		public void IntPart_7 ()
		{
			Assert.Equals (IntOps.IntPart (123.456m), 123);
		}
		[Test]
		public void IntPart_8 ()
		{
			Assert.Equals (IntOps.IntPart (-123.456m), -123);
		}

		[Test]
		public void IntPart64_1 ()
		{
			Assert.Equals (IntOps.IntPart64 (0.123), 0L);
		}
		[Test]
		public void IntPart64_2 ()
		{
			Assert.Equals (IntOps.IntPart64 (-0.123), 0L);
		}
		[Test]
		public void IntPart64_3 ()
		{
			Assert.Equals (IntOps.IntPart64 (123.456), 123L);
		}
		[Test]
		public void IntPart64_4 ()
		{
			Assert.Equals (IntOps.IntPart64 (-123.456), -123L);
		}
		[Test]
		public void IntPart64_5 ()
		{
			Assert.Equals (IntOps.IntPart64 (0.123m), 0L);
		}
		[Test]
		public void IntPart64_6 ()
		{
			Assert.Equals (IntOps.IntPart64 (-0.123m), 0L);
		}
		[Test]
		public void IntPart64_7 ()
		{
			Assert.Equals (IntOps.IntPart64 (123.456m), 123L);
		}
		[Test]
		public void IntPart64_8 ()
		{
			Assert.Equals (IntOps.IntPart64 (-123.456m), -123L);
		}
	}
}
